#!/bin/sh
# test we are root
if [ "$(id -u)" != "0" ]; then
   exit 1
fi

# not permitted with ‘-fno-rtti...use ‘-fexceptions’ to enable
export CFLAGS="-mtune=generic -Os -pipe"
export CXXFLAGS="-mtune=generic -Os -pipe -fexceptions"

P=worker
V=5.1.0
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc libX11-dev zstd file-dev imagemagick setconf libXinerama-dev libXft-dev"
for Z in $LIST
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp # disable libX11 dev did not make a console FM for me 
su -c "/usr/local/bin/wget -nc --no-check-certificate \
http://www.boomerangsworld.de/cms/$P/downloads/$SRC.tar.zst " $USER 
unzstd $SRC*zst && tar xvf $SRC.tar
cd $SRC 
./configure --prefix=/usr/local  --with-libmagic --with-x 
# AVFS usage                  : no
# Large file support          : yes
# Regular expressions support : yes
# X11 XIM usage               : yes
# X11 Xinerama support        : yes
# UTF8 support                : yes
# Libmagic support            : yes
# DBUS device handling        : no
# Inotify support             : yes
# LUA support                 : no
# Font engine                 : Xft
# OpenSSL SHA256              : no
# Maximum command line length : 32768
# Installation prefix           : /usr/local
make -j4 # 1M 10s
make install-strip DESTDIR=/tmp/$P 
cd /tmp

# doc
#######
mkdir -p $P-doc/usr/local/share
mv  $P/usr/local/share/man $P-doc/usr/local/share

# main
######
mkdir -p $P/usr/local/share/doc/$P
echo 'GPL v2' > $P/usr/local/share/doc/$P/COPYING

# desktop
DESK=$P/usr/local/share/applications/$P.desktop
convert $P/usr/local/share/pixmaps/WorkerIcon48.xpm $P/usr/local/share/pixmaps/worker.png
setconf $DESK Icon worker
echo 'X-FullPathIcon=/usr/local/share/pixmaps/worker.png' >> $DESK

# some of my prefs put into En config not foreign configs
# Avoid move to trash unless your desktop has such support
CONF=$P/usr/local/share/worker/config-english
sed 's|evince|flaxpdf|' -i $CONF
sed 's|mplayer|mpv|' -i $CONF
sed 's|khexedit|hexedit|' -i $CONF
sed 's|soffice|abiword|' -i $CONF
sed 's|gimp|mtpaint|' -i $CONF
# next affects internal edit
sed 's|{scripts}/xeditor|xterm -e nano {A}|' -i $CONF
# imagemagick command = display -> no change

# install script
################
mkdir -p $P/usr/local/tce.installed
cat >> $P/usr/local/tce.installed/$P <<'EOF'
#!/bin/sh
update-mime-database /usr/local/share/mime > /dev/null 2>&1
EOF
chown -R root:staff $P/usr/local/tce.installed
chmod -R 775 $P/usr/local/tce.installed


# TCZ them
###########
LIST2="$P $P-doc"
for Z in $LIST2
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'Title:          worker-doc.tcz
Description:    man page
Version:        5.1.0
Author:         Ralf Hoffmann
Original-site:  http://www.boomerangsworld.de/cms/worker
Copying-policy: GPL v2
Size:           8.0K
Extension_by:   aus9 @linuxquestions.org
Tags:           cli terminal file manager
Comments:       En man page standard pathway
                Fr & It non-std pathway
                
Change-log:     2024/08/05 v 5.1.0 on 15x
Current:        2024/08/05   ' > $P-doc.tcz.info
echo 'man-db.tcz ' > $P-doc.tcz.dep

echo 'Title:          worker.tcz
Description:    2-pane terminal file manager (not console)
Version:        5.1.0
Author:         Ralf Hoffmann
Original-site:  http://www.boomerangsworld.de/cms/worker
Copying-policy: GPL v2
Size:           2.5M
Extension_by:   aus9 @linuxquestions.org
Tags:           cli terminal file manager
Comments:       First run sets up $HOME/.config/worker dir & files
                Unlike mc, worker opens in a new window.
                Popup offers to configure 12 European languages 
                EN config has been modified for some TCEs as below. 
                I have not attempted to convert all executables to our TCEs
                If you edit, popup will request restart worker. 
       
                No udisks support compiled so use mnttool pls
                aterm has dependencies for worker but you are free to 
                use your preferred terminal.
                Click (or double click) button top LH corner next to 
                A button allows GUI config edits if you do not want manual edits

                Can use kb hotkeys or mouse clicks similar to mc.
                Hotkeys can be changed. 

                If you load extra TCEs you would like worker to use,
                please run 
                $ /usr/local/tce.installed/shared-mime-info

                Both F3 & F4 font remains black font and "Floating" popup opens

                Internal edit (F4) uses "xterm -e nano {A}"
                which works with aterm and lxterminal.
                Edit config to to your preferred terminal if you prefer
                internal edits. Ditto change nano to your preferred CLI editor.
                Otherwise use GUI TCE for edits (eg) "leafpad {A}" 
                ---> then F4 will open a GUI text editor.

                F8 (delete) 
                ###########
                Please look at the file & dir count at top of selected pane shown in Red
                clicking on a file/dir multiple times toggles the font
                from black -> white -> black in a loop
                ONLY white font will be deleted
                (Actually only white font can be actioned such as move copy etc)
                If you click "invert selection button" all files/dirs are white font
                Here is an example = Files 1/9 Dirs 2/10 means 3 items have been
                highlighted for deletion. F8 -> Then a popup warns about non-empty dirs

                Optional deps Use enter button, not F3/F4 to open external TCE
                Read info files for supported formats and extra dependencies
                abiword, audacious, flaxpdf, imagemagick, leafpad, mpv & mtpaint(-gtk3)  

                Bottom BUTTONS
                Options to move to trash can are dependent on your desktop
                supporting such. 
                Hover mouse for hints for most buttons.
                Note to go up dir in mc, page up to get to top of sub-dir 
                then press enter against /..
                In worker we just use the backspace            
                
Change-log:     2024/08/05 v 5.1.0 on 15x
Current:        2024/08/05   ' > $P.tcz.info

readelf -d $P/usr/local/bin/$P | grep 'NEEDED' 
# needs a terminal so aterm dep
#libSM.so.6]libSM -> aterm
#libICE.so.6]libICE -> aterm
#libX11.so.6]libX11
#libmagic.so.1]file
#libXft.so.2] libXft
#libXinerama.so.1]libXinerama

echo 'aterm.tcz
libX11.tcz
file.tcz
libXft.tcz
libXinerama.tcz 
xdg-utils.tcz
nano.tcz' > $P.tcz.dep

submitqc --libs
rm -rf *.zsync

